# Google_Play_App_Info
A simple api to fetch Playstore App information.With this python script you will be able to get an app information in a jiffy.

### Prerequisites

> python3
  
  
### Dependencies

Install the following three python modules before executing Google_Play_App_Info
- re
- beautifulsoup4
- requests

```
pip install re

pip install bs4

pip install requests
```
OR 

Quickly resolve dependencies using:

```
pip install -r requirements.txt
```

### Usage

> python main.py



### Screenshots

###### Output

![OutputFile](https://raw.githubusercontent.com/gauthamp10/Google_Play_App_Info/master/Screenie/output.png)



### Author

 **Gautham Prakash**
 
 My other projects:[github.com/gauthamp10](https://gauthamp10.github.io/)
 
### Contributors

 *  [Ajo Vadakkan](https://www.facebook.com/ajoy.pappa) 
 *  [Jithin Koshy](https://github.com/JithinKoshy)
 
 Thanks to all contributors who helped me with my project

### License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details
